/*
 * Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __TIZEN_EMAIL_SERVICE_DOC_H__
#define __TIZEN_EMAIL_SERVICE_DOC_H__

/**
 * @ingroup CAPI_MESSAGING_FRAMEWORK
 * @defgroup EMAIL_SERVICE_FRAMEWORK email-service
 * @brief The Platform API for email functionalities.
 *
 * @addtogroup EMAIL_SERVICE_FRAMEWORK
 *
 * @section EMAIL_SERVICE_FRAMEWORK_HEADER Required Header
 *   \#include <email-api.h>
 *
 * @section EMAIL_SERVICE_FRAMEWORK_OVERVIEW Overview
 * Electronic mail, most commonly abbreviated email or e-mail, is a method of exchanging digital messages. 
 * E-mail systems are based on a store-and-forward model in which e-mail server computer systems accept, 
 * forward, deliver and store messages on behalf of users, who only need to connect to the e-mail infrastructure, 
 * typically an e-mail server, with a network-enabled device for the duration of message submission or retrieval.
 * The email-service API is implemented to provide functionalities to applications that make use of email service.
 * The email-service API can be utilized by any component in the application layer which facilitates the end user 
 * to perform the email realted operations such as save, send, download email message and others.
 * For Example, the email-service API’s shall be invoked by 1) Multimedia when user opts to send media file through email 
 * 2) Email application when user tries to send an email message etc.
 *
 * <table>
 * <tr>
 *      <th>Feature</th>
 *      <th>Description</th>
 * </tr>
 * <tr>
 *      <td>Account API</td>
 *      <td>Account API is a set of operations to manage email accounts like add, update, delete or get account related details.</td>
 * </tr>
 * <tr>
 *      <td>Other API</td>
 *      <td>Various API set for initializing and MIME operations and verifying email address. </td>
 * </tr>
 *  <tr>
 *      <td>Mail API</td>
 *      <td>Mail API is a set of operations to manage mail like add, update, delete or get mail related details.</td>
 * </tr>
 * <tr>
 *      <td>Mailbox API</td>
 *      <td>Mailbox API is a set of operations to manage email mailboxes like add, update, delete or get mailbox related details.</td>
 * </tr>
 * <tr>
 *      <td>Network API</td>
 *      <td>Network API is a set of operations to manage email send, receive and cancel related details.</td>
 * </tr>
 * <tr>
 *      <td>Rule API</td>
 *      <td>Rule API is a set of operations to manage email rules like add, get, delete or update rule related details.</td>
 * </tr>
 * <tr>
 *      <td>SMIME API</td>
 *      <td>SMIME API is a set of operations to handle SMIME data for secured email. </td>
 * </tr>
 * </table>
 */

#endif /* __TIZEN_EMAIL_SERVICE_DOC_H__ */





